@@ -1,3 +1,4 @@
+from copy import deepcopy
 from tqdm import trange
 from collections import defaultdict
 from classicmagedps.env import FireEnvironment
@@ -14,6 +15,7 @@ class Simulation:
             'dps': defaultdict(list),
             'avg_mage_dps': [],
             'uptime': [],
+            '5 stack uptime': [],
             'avg_tick': []
         }
 
@@ -23,7 +25,8 @@ class Simulation:
             env = self.env_class()
             env.debuffs.coe = self.coe
             env.PRINT = False
-            env.add_mages(self.mages)
+            mages = [deepcopy(mage) for mage in self.mages]
+            env.add_mages(mages)
 
             env.run(until=duration)
 
@@ -31,6 +34,7 @@ class Simulation:
                 self.results['dps'][mage].append(mdps)
             self.results['avg_mage_dps'].append(env.meter.raid_dmg())
             self.results['uptime'].append(env.ignite.uptime)
+            self.results['5 stack uptime'].append(env.ignite.uptime_5_stacks)
             self.results['avg_tick'].append(env.ignite.avg_tick)
 
         self.report()
@@ -41,6 +45,7 @@ class Simulation:
 
         print(f"Average mage dps: {mean(self.results['avg_mage_dps'])}")
         print(f"Average ignite uptime : {100 * mean(self.results['uptime'])}%")
+        print(f"Average 5 stack ignite uptime : {100 * mean(self.results['5 stack uptime'])}%")
         print(f"Average ignite tick : {mean(self.results['avg_tick'])}")
 
 
